# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel
from .browserbase_setup import BrowserbaseSetup
from .browserbase_create_session_arguments import BrowserbaseCreateSessionArguments

__all__ = ["BrowserbaseCreateSessionIntegrationDef"]


class BrowserbaseCreateSessionIntegrationDef(BaseModel):
    arguments: Optional[BrowserbaseCreateSessionArguments] = None

    method: Optional[Literal["create_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[BrowserbaseSetup] = None
    """The setup parameters for the browserbase integration"""
