# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["ChosenBash20241022"]


class ChosenBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None
