# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["AlgoliaSetup"]


class AlgoliaSetup(BaseModel):
    algolia_api_key: str

    algolia_application_id: str
